# Generated by roxygen2: do not edit by hand

S3method(L1cent,igraph)
S3method(L1cent,matrix)
S3method(L1centEDGE,igraph)
S3method(L1centEDGE,matrix)
S3method(L1centGROUP,igraph)
S3method(L1centGROUP,matrix)
S3method(L1centLOC,igraph)
S3method(L1centLOC,matrix)
S3method(L1centMDS,igraph)
S3method(L1centMDS,matrix)
S3method(L1centNB,igraph)
S3method(L1centNB,matrix)
S3method(group_reduce,igraph)
S3method(group_reduce,matrix)
S3method(plot,L1cent)
S3method(plot,L1centEDGE)
S3method(plot,L1centLOC)
S3method(plot,L1centMDS)
S3method(print,L1cent)
S3method(print,L1centEDGE)
S3method(print,L1centGROUP)
S3method(print,L1centLOC)
S3method(print,L1centMDS)
S3method(print,L1centNB)
S3method(summary,L1cent)
S3method(summary,L1centEDGE)
S3method(summary,L1centLOC)
S3method(summary,L1centNB)
export(Gini)
export(L1cent)
export(L1centEDGE)
export(L1centGROUP)
export(L1centLOC)
export(L1centMDS)
export(L1centNB)
export(Lorenz_plot)
export(group_reduce)
importFrom(Rcpp,sourceCpp)
importFrom(foreach,"%dopar%")
importFrom(graphics,lines)
importFrom(graphics,text)
importFrom(igraph,distances)
importFrom(stats,aggregate)
importFrom(stats,cmdscale)
importFrom(stats,dist)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(utils,flush.console)
importFrom(withr,local_par)
useDynLib(L1centrality, .registration = TRUE)
